@@ -44,6 +44,17 @@ namespace xt
             xtensor_dynamic ca(cm.m_shape, layout_type::column_major);
             compare_shape(ca, cm);
         }
+
+        {
+            SCOPED_TRACE("from shape");
+            std::array<std::size_t, 3> shp = {5,4,2};
+            std::vector<std::size_t> shp_as_vec = {5,4,2};
+            auto ca = xtensor<int, 3>::from_shape({3,2,1});
+            auto cb = xtensor<int, 3>::from_shape(shp_as_vec);
+            std::vector<std::size_t> expected_shape = {3, 2, 1};
+            EXPECT_TRUE(std::equal(expected_shape.begin(), expected_shape.end(), ca.shape().begin()));
+            EXPECT_TRUE(std::equal(shp.begin(), shp.end(), cb.shape().begin()));
+        }
     }
 
     TEST(xtensor, strided_constructor)
@@ -184,4 +195,16 @@ namespace xt
         xtensor_dynamic a;
         EXPECT_EQ(0, a());
     }
+
+    TEST(xtensor, xiterator)
+    {
+        xtensor_dynamic a;
+        test_xiterator<xtensor_dynamic, container_type>(a);
+    }
+
+    TEST(xtensor, reverse_xiterator)
+    {
+        xtensor_dynamic a;
+        test_reverse_xiterator<xtensor_dynamic, container_type>(a);
+    }
 }
